//
//  TabBarController.swift
//  Tabs
//
//  Created by Bart Jacobs on 21/08/2018.
//  Copyright © 2018 Cocoacasts. All rights reserved.
//

import UIKit

class TabBarController: UITabBarController {

    // MARK: - Properties
    
    var applicationManager: ApplicationManager?
    
    // MARK: - View Life Cycle
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // Setup Child View Controllers
        setupChildViewControllers()
    }
    
    // MARK: - Helper Methods
    
    private func setupChildViewControllers() {
        guard let viewControllers = viewControllers else {
            return
        }
        
        for viewController in viewControllers {
            var childViewController: UIViewController?
            
            if let navigationController = viewController as? UINavigationController {
                childViewController = navigationController.viewControllers.first
            } else {
                childViewController = viewController
            }
            
            switch childViewController {
            case let viewController as RedViewController:
                // Configure View Controller
                viewController.title = "Red"
                viewController.color = UIColor.red
            case let viewController as GreenViewController:
                // Initialize View Model
                let viewModel = GreenViewModel(title: "Green")
                
                // Configure View Controller
                viewController.title = "Green"
                viewController.viewModel = viewModel
            case let viewController as BlueViewController:
                // Configure View Controller
                viewController.title = "Blue"
                viewController.applicationManager = applicationManager
            default:
                break
            }
        }
    }
    
}
